@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2010, 2011, 2012, 2016 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2010, 2011, 2012, 2016, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,6 +66,7 @@ LoadScreen::LoadScreen(QWidget* parent) :
 	m_hide_effect = new QGraphicsOpacityEffect(this);
 	m_hide_effect->setOpacity(1.0);
 	setGraphicsEffect(m_hide_effect);
+	m_hide_effect->setEnabled(false);
 
 	m_hide_timer = new QTimer(this);
 	m_hide_timer->setInterval(30);
@@ -108,6 +109,7 @@ void LoadScreen::setText(const QString& step)
 		m_hide_timer->stop();
 	}
 	m_hide_effect->setOpacity(1.0);
+	m_hide_effect->setEnabled(false);
 
 	show();
 	raise();
@@ -119,6 +121,7 @@ void LoadScreen::setText(const QString& step)
 void LoadScreen::finish()
 {
 	m_hide_effect->setOpacity(1.0);
+	m_hide_effect->setEnabled(true);
 	m_hide_timer->start();
 }
 
@@ -156,6 +159,7 @@ void LoadScreen::fade()
 	if (m_hide_effect->opacity() <= 0.01) {
 		m_hide_timer->stop();
 		hide();
+		m_hide_effect->setEnabled(false);
 	}
 }
 
